==> easyapi-0.8.3-sources.jar: cn/easyutil/easyapi/filter/config/ReadInterfaceConfig.java <==
package cn.easyutil.easyapi.filter.config;

import cn.easyutil.easyapi.filter.readInterface.*;

import java.util.ArrayList;
import java.util.List;

public class ReadInterfaceConfig {

    List<ReadInterfaceBodyType> readBodyTypes = new ArrayList<>();
    List<ReadInterfaceCustomSearch> readCustomSearch = new ArrayList<>();
    List<ReadInterfaceDescription> readDescription = new ArrayList<>();
    List<ReadInterfaceEnableReqPackage> readReqPackages = new ArrayList<>();
    List<ReadInterfaceEnableResPackage> readResPackages = new ArrayList<>();
    List<ReadInterfaceIgnore> readIgnore = new ArrayList<>();
    List<ReadInterfaceRenewType> readRenewTypes = new ArrayList<>();
    List<ReadInterfaceRequestMethod> readRequestMethods = new ArrayList<>();
    List<ReadInterfaceRequestUrl> readRequestUrls = new ArrayList<>();
    List<ReadInterfaces> readInterfaces = new ArrayList<>();
    List<ReadInterfaceShow> readShows = new ArrayList<>();
    List<ReadInterfaceShowName> readShowNames = new ArrayList<>();
    List<ReadInterfaceUnique> readUniques = new ArrayList<>();
    List<ReadInterfaceVerifyMockTag> readVerifyMockTags = new ArrayList<>();

    public void addReadBodyTypeFilter(ReadInterfaceBodyType readBodyType) {
        this.readBodyTypes.add(readBodyType);
    }

    public void addReadCustomSearchFilter(ReadInterfaceCustomSearch readCustomSearch) {
        this.readCustomSearch.add(readCustomSearch);
    }

    public void addReadDescriptionFilter(ReadInterfaceDescription readDescription) {
        this.readDescription.add(readDescription);
    }

    public void addReadReqPackagesFilter(ReadInterfaceEnableReqPackage readReqPackages) {
        this.readReqPackages.add(readReqPackages);
    }

    public void addReadResPackagesFilter(ReadInterfaceEnableResPackage readResPackages) {
        this.readResPackages.add(readResPackages);
    }

    public void addReadIgnoreFilter(ReadInterfaceIgnore readIgnore) {
        this.readIgnore.add(readIgnore);
    }

    public void addReadRenewTypesFilter(ReadInterfaceRenewType readRenewTypes) {
        this.readRenewTypes.add(readRenewTypes);
    }

    public void addReadRequestMethodsFilter(ReadInterfaceRequestMethod readRequestMethods) {
        this.readRequestMethods.add(readRequestMethods);
    }

    public void addReadRequestUrlsFilter(ReadInterfaceRequestUrl readRequestUrls) {
        this.readRequestUrls.add(readRequestUrls);
    }

    public void addReadInterfacesFilter(ReadInterfaces readInterfaces) {
        this.readInterfaces.add(readInterfaces);
    }

    public void addReadShowsFilter(ReadInterfaceShow readShows) {
        this.readShows.add(readShows);
    }

    public void addReadShowNamesFilter(ReadInterfaceShowName readShowNames) {
        this.readShowNames.add(readShowNames);
    }

    public void addReadUniquesFilter(ReadInterfaceUnique readUniques) {
        this.readUniques.add(readUniques);
    }

    public void addReadVerifyMockTagsFilter(ReadInterfaceVerifyMockTag readVerifyMockTags) {
        this.readVerifyMockTags.add(readVerifyMockTags);
    }

    public List<ReadInterfaceBodyType> getReadBodyTypes() {
        return readBodyTypes;
    }

    public List<ReadInterfaceCustomSearch> getReadCustomSearch() {
        return readCustomSearch;
    }

    public List<ReadInterfaceDescription> getReadDescription() {
        return readDescription;
    }

    public List<ReadInterfaceEnableReqPackage> getReadReqPackages() {
        return readReqPackages;
    }

    public List<ReadInterfaceEnableResPackage> getReadResPackages() {
        return readResPackages;
    }

    public List<ReadInterfaceIgnore> getReadIgnore() {
        return readIgnore;
    }

    public List<ReadInterfaceRenewType> getReadRenewTypes() {
        return readRenewTypes;
    }

    public List<ReadInterfaceRequestMethod> getReadRequestMethods() {
        return readRequestMethods;
    }

    public List<ReadInterfaceRequestUrl> getReadRequestUrls() {
        return readRequestUrls;
    }

    public List<ReadInterfaces> getReadInterfaces() {
        return readInterfaces;
    }

    public List<ReadInterfaceShow> getReadShows() {
        return readShows;
    }

    public List<ReadInterfaceShowName> getReadShowNames() {
        return readShowNames;
    }

    public List<ReadInterfaceUnique> getReadUniques() {
        return readUniques;
    }

    public List<ReadInterfaceVerifyMockTag> getReadVerifyMockTags() {
        return readVerifyMockTags;
    }
}

==> easyapi-0.8.5.3-sources.jar: cn/easyutil/easyapi/filter/config/ReadInterfaceConfig.java <==
package cn.easyutil.easyapi.filter.config;

import cn.easyutil.easyapi.filter.readInterface.*;

import java.util.ArrayList;
import java.util.List;

public class ReadInterfaceConfig {

    List<ReadInterfaceBodyType> readBodyTypes = new ArrayList<>();
    List<ReadInterfaceCustomSearch> readCustomSearch = new ArrayList<>();
    List<ReadInterfaceDescription> readDescription = new ArrayList<>();
    List<ReadInterfaceEnableReqPackage> readReqPackages = new ArrayList<>();
    List<ReadInterfaceEnableResPackage> readResPackages = new ArrayList<>();
    List<ReadInterfaceIgnore> readIgnore = new ArrayList<>();
    List<ReadInterfaceRenewType> readRenewTypes = new ArrayList<>();
    List<ReadInterfaceRequestMethod> readRequestMethods = new ArrayList<>();
    List<ReadInterfaceRequestUrl> readRequestUrls = new ArrayList<>();
    List<ReadInterfaces> readInterfaces = new ArrayList<>();
    List<ReadInterfaceShow> readShows = new ArrayList<>();
    List<ReadInterfaceShowName> readShowNames = new ArrayList<>();
    List<ReadInterfaceUnique> readUniques = new ArrayList<>();
    List<ReadInterfaceVerifyMockTag> readVerifyMockTags = new ArrayList<>();
    List<ReadInterfaceRequestParamRemark> readRequestParamRemark = new ArrayList<>();
    List<ReadInterfaceResponseParamRemark> readResponseParamRemark = new ArrayList<>();

    public void addReadBodyTypeFilter(ReadInterfaceBodyType readBodyType) {
        this.readBodyTypes.add(readBodyType);
    }

    public void addReadCustomSearchFilter(ReadInterfaceCustomSearch readCustomSearch) {
        this.readCustomSearch.add(readCustomSearch);
    }

    public void addReadDescriptionFilter(ReadInterfaceDescription readDescription) {
        this.readDescription.add(readDescription);
    }

    public void addReadReqPackagesFilter(ReadInterfaceEnableReqPackage readReqPackages) {
        this.readReqPackages.add(readReqPackages);
    }

    public void addReadResPackagesFilter(ReadInterfaceEnableResPackage readResPackages) {
        this.readResPackages.add(readResPackages);
    }

    public void addReadIgnoreFilter(ReadInterfaceIgnore readIgnore) {
        this.readIgnore.add(readIgnore);
    }

    public void addReadRenewTypesFilter(ReadInterfaceRenewType readRenewTypes) {
        this.readRenewTypes.add(readRenewTypes);
    }

    public void addReadRequestMethodsFilter(ReadInterfaceRequestMethod readRequestMethods) {
        this.readRequestMethods.add(readRequestMethods);
    }

    public void addReadRequestUrlsFilter(ReadInterfaceRequestUrl readRequestUrls) {
        this.readRequestUrls.add(readRequestUrls);
    }

    public void addReadRequestParamRemarkFilter(ReadInterfaceRequestParamRemark remark) {
        this.readRequestParamRemark.add(remark);
    }

    public void addReadResponseParamRemarkFilter(ReadInterfaceResponseParamRemark remark) {
        this.readResponseParamRemark.add(remark);
    }

    public void addReadInterfacesFilter(ReadInterfaces readInterfaces) {
        this.readInterfaces.add(readInterfaces);
    }

    public void addReadShowsFilter(ReadInterfaceShow readShows) {
        this.readShows.add(readShows);
    }

    public void addReadShowNamesFilter(ReadInterfaceShowName readShowNames) {
        this.readShowNames.add(readShowNames);
    }

    public void addReadUniquesFilter(ReadInterfaceUnique readUniques) {
        this.readUniques.add(readUniques);
    }

    public void addReadVerifyMockTagsFilter(ReadInterfaceVerifyMockTag readVerifyMockTags) {
        this.readVerifyMockTags.add(readVerifyMockTags);
    }

    public List<ReadInterfaceBodyType> getReadBodyTypes() {
        return readBodyTypes;
    }

    public List<ReadInterfaceCustomSearch> getReadCustomSearch() {
        return readCustomSearch;
    }

    public List<ReadInterfaceDescription> getReadDescription() {
        return readDescription;
    }

    public List<ReadInterfaceEnableReqPackage> getReadReqPackages() {
        return readReqPackages;
    }

    public List<ReadInterfaceEnableResPackage> getReadResPackages() {
        return readResPackages;
    }

    public List<ReadInterfaceIgnore> getReadIgnore() {
        return readIgnore;
    }

    public List<ReadInterfaceRenewType> getReadRenewTypes() {
        return readRenewTypes;
    }

    public List<ReadInterfaceRequestMethod> getReadRequestMethods() {
        return readRequestMethods;
    }

    public List<ReadInterfaceRequestUrl> getReadRequestUrls() {
        return readRequestUrls;
    }

    public List<ReadInterfaces> getReadInterfaces() {
        return readInterfaces;
    }

    public List<ReadInterfaceShow> getReadShows() {
        return readShows;
    }

    public List<ReadInterfaceShowName> getReadShowNames() {
        return readShowNames;
    }

    public List<ReadInterfaceUnique> getReadUniques() {
        return readUniques;
    }

    public List<ReadInterfaceVerifyMockTag> getReadVerifyMockTags() {
        return readVerifyMockTags;
    }

    public List<ReadInterfaceRequestParamRemark> getReadRequestParamRemark() {
        return readRequestParamRemark;
    }

    public List<ReadInterfaceResponseParamRemark> getReadResponseParamRemark() {
        return readResponseParamRemark;
    }
}
